@@ -1,21 +1,6 @@
-# vim: ft=python fileencoding=utf-8 sts=4 sw=4 et:
-
-# Copyright 2014-2021 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
+# SPDX-FileCopyrightText: Florian Bruhin (The Compiler) <mail@qutebrowser.org>
 #
-# This file is part of qutebrowser.
-#
-# qutebrowser is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# qutebrowser is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with qutebrowser.  If not, see <https://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 """In qutebrowser, all keybindings are mapped to commands.
 
@@ -29,6 +14,8 @@ For command arguments, there are also some variables you can use:
 - `{url:host}`, `{url:domain}`, `{url:auth}`, `{url:scheme}`, `{url:username}`,
   `{url:password}`, `{url:port}`, `{url:path}` and `{url:query}`
   expand to the respective parts of the current URL
+- `{url:yank}` expands to the URL of the current page but strips all the query
+  parameters in the `url.yank_ignored_parameters` setting.
 - `{title}` expands to the current page's title
 - `{clipboard}` expands to the clipboard contents
 - `{primary}` expands to the primary selection contents
