@@ -1,42 +1,35 @@
-# vim: ft=python fileencoding=utf-8 sts=4 sw=4 et:
+# SPDX-FileCopyrightText: Florian Bruhin (The Compiler) <mail@qutebrowser.org>
+#
+# SPDX-License-Identifier: GPL-3.0-or-later
 
-# Copyright 2018-2021 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
-#
-# This file is part of qutebrowser.
-#
-# qutebrowser is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# qutebrowser is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with qutebrowser.  If not, see <https://www.gnu.org/licenses/>.
+# To allow count being documented
+# pylint: disable=differing-param-doc
 
 """Various commands."""
 
 import os
 import signal
-import functools
 import logging
+import pathlib
 from typing import Optional
+from collections.abc import Sequence, Callable
 
 try:
     import hunter
 except ImportError:
     hunter = None
 
-from PyQt5.QtCore import Qt
-from PyQt5.QtPrintSupport import QPrintPreviewDialog
+from qutebrowser.qt.core import Qt
+from qutebrowser.qt.printsupport import QPrintPreviewDialog
 
 from qutebrowser.api import cmdutils, apitypes, message, config
 
 # FIXME should be part of qutebrowser.api?
 from qutebrowser.completion.models import miscmodels
+from qutebrowser.utils import utils
+
+
+_LOGGER = logging.getLogger('misc')
 
 
 @cmdutils.register(name='reload')
@@ -67,31 +60,29 @@ def stop(tab: Optional[apitypes.Tab]) -> None:
 
 def _print_preview(tab: apitypes.Tab) -> None:
     """Show a print preview."""
-    def print_callback(ok: bool) -> None:
-        if not ok:
-            message.error("Printing failed!")
-
     tab.printing.check_preview_support()
     diag = QPrintPreviewDialog(tab)
-    diag.setAttribute(Qt.WA_DeleteOnClose)
+    diag.setAttribute(Qt.WidgetAttribute.WA_DeleteOnClose)
     diag.setWindowFlags(
-        diag.windowFlags() |  # type: ignore[operator, arg-type]
-        Qt.WindowMaximizeButtonHint |
-        Qt.WindowMinimizeButtonHint)
-    diag.paintRequested.connect(functools.partial(
-        tab.printing.to_printer, callback=print_callback))
+        diag.windowFlags() |
+        Qt.WindowType.WindowMaximizeButtonHint |
+        Qt.WindowType.WindowMinimizeButtonHint)
+    diag.paintRequested.connect(tab.printing.to_printer)
     diag.exec()
 
 
-def _print_pdf(tab: apitypes.Tab, filename: str) -> None:
+def _print_pdf(tab: apitypes.Tab, path: pathlib.Path) -> None:
     """Print to the given PDF file."""
     tab.printing.check_pdf_support()
-    filename = os.path.expanduser(filename)
-    directory = os.path.dirname(filename)
-    if directory and not os.path.exists(directory):
-        os.mkdir(directory)
-    tab.printing.to_pdf(filename)
-    logging.getLogger('misc').debug("Print to file: {}".format(filename))
+    path = path.expanduser()
+
+    try:
+        path.parent.mkdir(parents=True, exist_ok=True)
+    except OSError as e:
+        raise cmdutils.CommandError(e)
+
+    tab.printing.to_pdf(path)
+    _LOGGER.debug(f"Print to file: {path}")
 
 
 @cmdutils.register(name='print')
@@ -99,7 +90,7 @@ def _print_pdf(tab: apitypes.Tab, filename: str) -> None:
 @cmdutils.argument('pdf', flag='f', metavar='file')
 def printpage(tab: Optional[apitypes.Tab],
               preview: bool = False, *,
-              pdf: str = None) -> None:
+              pdf: Optional[pathlib.Path] = None) -> None:
     """Print the current/[count]th tab.
 
     Args:
@@ -155,6 +146,45 @@ def debug_dump_page(tab: apitypes.Tab, dest: str, plain: bool = False) -> None:
     tab.dump_async(callback, plain=plain)
 
 
+@cmdutils.register()
+@cmdutils.argument('tab', value=cmdutils.Value.cur_tab)
+def screenshot(
+        tab: apitypes.Tab,
+        filename: pathlib.Path,
+        *,
+        rect: str = None,
+        force: bool = False,
+) -> None:
+    """Take a screenshot of the currently shown part of the page.
+
+    The file format is automatically determined based on the given file extension.
+
+    Args:
+        filename: The file to save the screenshot to (~ gets expanded).
+        rect: The rectangle to save, as a string like WxH+X+Y.
+        force: Overwrite existing files.
+    """
+    expanded = filename.expanduser()
+    if expanded.exists() and not force:
+        raise cmdutils.CommandError(
+            f"File {filename} already exists (use --force to overwrite)")
+
+    try:
+        qrect = None if rect is None else utils.parse_rect(rect)
+    except ValueError as e:
+        raise cmdutils.CommandError(str(e))
+
+    pic = tab.grab_pixmap(qrect)
+    if pic is None:
+        raise cmdutils.CommandError("Getting screenshot failed")
+
+    ok = pic.save(str(expanded))
+    if not ok:
+        raise cmdutils.CommandError(f"Saving to {filename} failed")
+
+    _LOGGER.debug(f"Screenshot saved to {filename}")
+
+
 @cmdutils.register(maxsplit=0)
 @cmdutils.argument('tab', value=cmdutils.Value.cur_tab)
 def insert_text(tab: apitypes.Tab, text: str) -> None:
@@ -176,13 +206,33 @@ def insert_text(tab: apitypes.Tab, text: str) -> None:
     tab.elements.find_focused(_insert_text_cb)
 
 
+def _wrap_find_at_pos(value: str, tab: apitypes.Tab,
+                      callback: Callable[[Optional[apitypes.WebElement]], None]
+                      ) -> None:
+    try:
+        point = utils.parse_point(value)
+    except ValueError as e:
+        message.error(str(e))
+        return
+    tab.elements.find_at_pos(point, callback)
+
+
+_FILTER_ERRORS = {
+    'id': lambda x: f'with ID "{x}"',
+    'css': lambda x: f'matching CSS selector "{x}"',
+    'focused': lambda _: 'with focus',
+    'position': lambda x: 'at position {x}',
+}
+
+
 @cmdutils.register()
 @cmdutils.argument('tab', value=cmdutils.Value.cur_tab)
-@cmdutils.argument('filter_', choices=['id'])
-def click_element(tab: apitypes.Tab, filter_: str, value: str, *,
+@cmdutils.argument('filter_', choices=['id', 'css', 'position', 'focused'])
+def click_element(tab: apitypes.Tab, filter_: str, value: str = None, *,  # noqa: C901
                   target: apitypes.ClickTarget =
                   apitypes.ClickTarget.normal,
-                  force_event: bool = False) -> None:
+                  force_event: bool = False,
+                  select_first: bool = False) -> None:
     """Click the element matching the given filter.
 
     The given filter needs to result in exactly one element, otherwise, an
@@ -190,27 +240,63 @@ def click_element(tab: apitypes.Tab, filter_: str, value: str, *,
 
     Args:
         filter_: How to filter the elements.
-                 id: Get an element based on its ID.
-        value: The value to filter for.
+
+            - id: Get an element based on its ID.
+            - css: Filter by a CSS selector.
+            - position: Click the element at specified position.
+               Specify `value` as 'x,y'.
+            - focused: Click the currently focused element.
+        value: The value to filter for. Optional for 'focused' filter.
         target: How to open the clicked element (normal/tab/tab-bg/window).
         force_event: Force generating a fake click event.
+        select_first: Select first matching element if there are multiple.
     """
-    def single_cb(elem: Optional[apitypes.WebElement]) -> None:
-        """Click a single element."""
-        if elem is None:
-            message.error("No element found with id {}!".format(value))
-            return
+    def do_click(elem: apitypes.WebElement) -> None:
         try:
             elem.click(target, force_event=force_event)
         except apitypes.WebElemError as e:
             message.error(str(e))
+
+    def single_cb(elem: Optional[apitypes.WebElement]) -> None:
+        """Click a single element."""
+        if elem is None:
+            message.error(f"No element found {_FILTER_ERRORS[filter_](value)}!")
             return
 
-    handlers = {
-        'id': (tab.elements.find_id, single_cb),
-    }
-    handler, callback = handlers[filter_]
-    handler(value, callback)
+        do_click(elem)
+
+    def multiple_cb(elems: Sequence[apitypes.WebElement]) -> None:
+        if not elems:
+            message.error(f"No element found {_FILTER_ERRORS[filter_](value)}!")
+            return
+
+        if not select_first and len(elems) > 1:
+            message.error(f"Multiple elements found {_FILTER_ERRORS[filter_](value)}!")
+            return
+
+        do_click(elems[0])
+
+    if value is None and filter_ != 'focused':
+        raise cmdutils.CommandError("Argument 'value' is only "
+                                    "optional with filter 'focused'!")
+
+    if filter_ == "id":
+        assert value is not None
+        tab.elements.find_id(elem_id=value, callback=single_cb)
+    elif filter_ == "css":
+        assert value is not None
+        tab.elements.find_css(
+            value,
+            callback=multiple_cb,
+            error_cb=lambda exc: message.error(str(exc)),
+        )
+    elif filter_ == "position":
+        assert value is not None
+        _wrap_find_at_pos(value, tab=tab, callback=single_cb)
+    elif filter_ == "focused":
+        tab.elements.find_focused(callback=single_cb)
+    else:
+        raise utils.Unreachable(filter_)
 
 
 @cmdutils.register(debug=True)
@@ -221,7 +307,7 @@ def debug_webaction(tab: apitypes.Tab, action: str, count: int = 1) -> None:
 
     Available actions:
     https://doc.qt.io/archives/qt-5.5/qwebpage.html#WebAction-enum (WebKit)
-    https://doc.qt.io/qt-5/qwebenginepage.html#WebAction-enum (WebEngine)
+    https://doc.qt.io/qt-6/qwebenginepage.html#WebAction-enum (WebEngine)
 
     Args:
         action: The action to execute, e.g. MoveToNextChar.
@@ -256,36 +342,42 @@ def nop() -> None:
 
 
 @cmdutils.register()
-def message_error(text: str) -> None:
+def message_error(text: str, rich: bool = False) -> None:
     """Show an error message in the statusbar.
 
     Args:
         text: The text to show.
+        rich: Render the given text as
+              https://doc.qt.io/qt-6/richtext-html-subset.html[Qt Rich Text].
     """
-    message.error(text)
+    message.error(text, rich=rich)
 
 
 @cmdutils.register()
 @cmdutils.argument('count', value=cmdutils.Value.count)
-def message_info(text: str, count: int = 1) -> None:
+def message_info(text: str, count: int = 1, rich: bool = False) -> None:
     """Show an info message in the statusbar.
 
     Args:
         text: The text to show.
-        count: How many times to show the message
+        count: How many times to show the message.
+        rich: Render the given text as
+              https://doc.qt.io/qt-6/richtext-html-subset.html[Qt Rich Text].
     """
     for _ in range(count):
-        message.info(text)
+        message.info(text, rich=rich)
 
 
 @cmdutils.register()
-def message_warning(text: str) -> None:
+def message_warning(text: str, rich: bool = False) -> None:
     """Show a warning message in the statusbar.
 
     Args:
         text: The text to show.
+        rich: Render the given text as
+              https://doc.qt.io/qt-6/richtext-html-subset.html[Qt Rich Text].
     """
-    message.warning(text)
+    message.warning(text, rich=rich)
 
 
 @cmdutils.register(debug=True)
@@ -296,6 +388,7 @@ def debug_crash(typ: str = 'exception') -> None:
     Args:
         typ: either 'exception' or 'segfault'.
     """
+    # pylint: disable=broad-exception-raised
     if typ == 'segfault':
         os.kill(os.getpid(), signal.SIGSEGV)
         raise Exception("Segfault failed (wat.)")
@@ -344,3 +437,9 @@ def devtools_focus(tab: apitypes.Tab) -> None:
         tab.data.splitter.cycle_focus()
     except apitypes.InspectorError as e:
         raise cmdutils.CommandError(e)
+
+
+@cmdutils.register(name='Ni!')
+def knights_who_say_ni() -> None:
+    """We are the Knights Who Say... 'Ni'!"""  # noqa: D400
+    raise cmdutils.CommandError("Do you demand a shrubbery?")
