@@ -1,51 +1,17 @@
 /* eslint-disable max-len, max-statements, complexity,
 default-case */
 
-// Copyright 2014 The Chromium Authors. All rights reserved.
-//
-// Redistribution and use in source and binary forms, with or without
-// modification, are permitted provided that the following conditions are
-// met:
-//
-//    * Redistributions of source code must retain the above copyright
-// notice, this list of conditions and the following disclaimer.
-//    * Redistributions in binary form must reproduce the above
-// copyright notice, this list of conditions and the following disclaimer
-// in the documentation and/or other materials provided with the
-// distribution.
-//    * Neither the name of Google Inc. nor the names of its
-// contributors may be used to endorse or promote products derived from
-// this software without specific prior written permission.
-//
-// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
-// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
-// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+/* Copyright 2014 The Chromium Authors
+ * Use of this source code is governed by a BSD-style license that can be
+ * found in the LICENSE file.
+ * https://source.chromium.org/chromium/chromium/src/+/main:LICENSE
+ */
+
 
 /**
- * Copyright 2018-2021 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
+ * SPDX-FileCopyrightText: Florian Bruhin (The Compiler) <mail@qutebrowser.org>
  *
- * This file is part of qutebrowser.
- *
- * qutebrowser is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * qutebrowser is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with qutebrowser.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
 /**
@@ -773,6 +739,12 @@ window._qutebrowser.caret = (function() {
      */
     CaretBrowsing.isWindows = null;
 
+    /**
+     * Whether we should log debug outputs.
+     * @type {boolean}
+     */
+    CaretBrowsing.isDebug = null;
+
     /**
      * The id returned by window.setInterval for our stopAnimation function, so
      * we can cancel it when we call stopAnimation again.
@@ -1184,6 +1156,8 @@ window._qutebrowser.caret = (function() {
             action = "extend";
         }
 
+        CaretBrowsing.debug(`(move) ${action} ${count} ${granularity} ${direction}, selection ${CaretBrowsing.selectionState}`);
+
         for (let i = 0; i < count; i++) {
             if (CaretBrowsing.selectionState === CaretBrowsing.SelectionState.LINE) {
                 CaretBrowsing.updateLineSelection(direction, granularity);
@@ -1214,6 +1188,8 @@ window._qutebrowser.caret = (function() {
         if (CaretBrowsing.selectionState !== CaretBrowsing.SelectionState.NONE) {
             action = "extend";
         }
+        CaretBrowsing.debug(`(moveToBlock) ${action} paragraph ${paragraph}, boundary ${boundary}, count ${count}, selection ${CaretBrowsing.selectionState}`);
+
         for (let i = 0; i < count; i++) {
             window.
                 getSelection().
@@ -1230,6 +1206,7 @@ window._qutebrowser.caret = (function() {
     };
 
     CaretBrowsing.toggle = function(value) {
+        CaretBrowsing.debug(`(toggle) enabled ${CaretBrowsing.isEnabled}, force ${CaretBrowsing.forceEnabled}`);
         if (CaretBrowsing.forceEnabled) {
             CaretBrowsing.recreateCaretElement();
             return;
@@ -1265,6 +1242,7 @@ window._qutebrowser.caret = (function() {
      * is enabled and whether this window / iframe has focus.
      */
     CaretBrowsing.updateIsCaretVisible = function() {
+        CaretBrowsing.debug(`(updateIsCaretVisible) isEnabled ${CaretBrowsing.isEnabled}, isWindowFocused ${CaretBrowsing.isWindowFocused}, isCaretVisible ${CaretBrowsing.isCaretVisible}, caretElement ${CaretBrowsing.caretElement}`);
         CaretBrowsing.isCaretVisible =
             (CaretBrowsing.isEnabled && CaretBrowsing.isWindowFocused);
         if (CaretBrowsing.isCaretVisible && !CaretBrowsing.caretElement) {
@@ -1308,6 +1286,12 @@ window._qutebrowser.caret = (function() {
         }
     };
 
+    CaretBrowsing.debug = (text) => {
+        if (CaretBrowsing.isDebug) {
+            console.debug(`caret: ${text}`);
+        }
+    }
+
     CaretBrowsing.init = function() {
         CaretBrowsing.isWindowFocused = document.hasFocus();
 
@@ -1347,6 +1331,7 @@ window._qutebrowser.caret = (function() {
 
     funcs.setFlags = (flags) => {
         CaretBrowsing.isWindows = flags.includes("windows");
+        CaretBrowsing.isDebug = flags.includes("debug");
     };
 
     funcs.disableCaret = () => {
