@@ -1,27 +1,12 @@
-# vim: ft=python fileencoding=utf-8 sts=4 sw=4 et:
-
-# Copyright 2014-2021 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
+# SPDX-FileCopyrightText: Florian Bruhin (The Compiler) <mail@qutebrowser.org>
 #
-# This file is part of qutebrowser.
-#
-# qutebrowser is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# qutebrowser is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with qutebrowser.  If not, see <https://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 """Base text widgets for statusbar."""
 
-from PyQt5.QtCore import Qt
-from PyQt5.QtWidgets import QLabel, QSizePolicy
-from PyQt5.QtGui import QPainter
+from qutebrowser.qt.core import Qt
+from qutebrowser.qt.widgets import QLabel, QSizePolicy
+from qutebrowser.qt.gui import QPainter
 
 from qutebrowser.utils import qtutils, utils
 
@@ -40,9 +25,9 @@ class TextBase(QLabel):
         _elided_text: The current elided text.
     """
 
-    def __init__(self, parent=None, elidemode=Qt.ElideRight):
+    def __init__(self, parent=None, elidemode=Qt.TextElideMode.ElideRight):
         super().__init__(parent)
-        self.setSizePolicy(QSizePolicy.Preferred, QSizePolicy.Minimum)
+        self.setSizePolicy(QSizePolicy.Policy.Preferred, QSizePolicy.Policy.Minimum)
         self._elidemode = elidemode
         self._elided_text = ''
 
@@ -57,7 +42,7 @@ class TextBase(QLabel):
         """
         if self.text():
             self._elided_text = self.fontMetrics().elidedText(
-                self.text(), self._elidemode, width, Qt.TextShowMnemonic)
+                self.text(), self._elidemode, width, Qt.TextFlag.TextShowMnemonic)
         else:
             self._elided_text = ''
 
@@ -68,7 +53,7 @@ class TextBase(QLabel):
             txt: The text to set (string).
         """
         super().setText(txt)
-        if self._elidemode != Qt.ElideNone:
+        if self._elidemode != Qt.TextElideMode.ElideNone:
             self._update_elided_text(self.geometry().width())
 
     def resizeEvent(self, e):
@@ -80,7 +65,7 @@ class TextBase(QLabel):
 
     def paintEvent(self, e):
         """Override QLabel::paintEvent to draw elided text."""
-        if self._elidemode == Qt.ElideNone:
+        if self._elidemode == Qt.TextElideMode.ElideNone:
             super().paintEvent(e)
         else:
             e.accept()
