@@ -1,21 +1,6 @@
-# vim: ft=python fileencoding=utf-8 sts=4 sw=4 et:
-
-# Copyright 2015-2021 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
+# SPDX-FileCopyrightText: Florian Bruhin (The Compiler) <mail@qutebrowser.org>
 #
-# This file is part of qutebrowser.
-#
-# qutebrowser is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# qutebrowser is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with qutebrowser.  If not, see <https://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 """Management of sessions - saved tabs/windows."""
 
@@ -25,13 +10,14 @@ import itertools
 import urllib
 import shutil
 import pathlib
-from typing import Any, Iterable, MutableMapping, MutableSequence, Optional, Union, cast
+from typing import Any, Optional, Union, cast
+from collections.abc import Iterable, MutableMapping, MutableSequence
 
-from PyQt5.QtCore import Qt, QUrl, QObject, QPoint, QTimer, QDateTime
+from qutebrowser.qt.core import Qt, QUrl, QObject, QPoint, QTimer, QDateTime
 import yaml
 
 from qutebrowser.utils import (standarddir, objreg, qtutils, log, message,
-                               utils, usertypes, version)
+                               utils, usertypes)
 from qutebrowser.api import cmdutils
 from qutebrowser.config import config, configfiles
 from qutebrowser.completion.models import miscmodels
@@ -64,12 +50,7 @@ def init(parent=None):
 
     # WORKAROUND for https://github.com/qutebrowser/qutebrowser/issues/5359
     backup_path = base_path / 'before-qt-515'
-
-    if objects.backend == usertypes.Backend.QtWebEngine:
-        webengine_version = version.qtwebengine_versions().webengine
-        do_backup = webengine_version >= utils.VersionNumber(5, 15)
-    else:
-        do_backup = False
+    do_backup = objects.backend == usertypes.Backend.QtWebEngine
 
     if base_path.exists() and not backup_path.exists() and do_backup:
         backup_path.mkdir()
@@ -225,7 +206,7 @@ class SessionManager(QObject):
             # QtWebEngine
             user_data = None
 
-        data['last_visited'] = item.lastVisited().toString(Qt.ISODate)
+        data['last_visited'] = item.lastVisited().toString(Qt.DateFormat.ISODate)
 
         if tab.history.current_idx() == idx:
             pos = tab.scroller.pos_px()
@@ -242,19 +223,30 @@ class SessionManager(QObject):
 
         return data
 
-    def _save_tab(self, tab, active):
+    def _save_tab(self, tab, active, with_history=True):
         """Get a dict with data for a single tab.
 
         Args:
             tab: The WebView to save.
             active: Whether the tab is currently active.
+            with_history: Include the tab's history.
         """
         data: _JsonType = {'history': []}
         if active:
             data['active'] = True
-        for idx, item in enumerate(tab.history):
+
+        history = tab.history if with_history else [tab.history.current_item()]
+
+        for idx, item in enumerate(history):
             qtutils.ensure_valid(item)
             item_data = self._save_tab_item(tab, idx, item)
+
+            if not item.url().isValid():
+                # WORKAROUND Qt 6.5 regression
+                # https://github.com/qutebrowser/qutebrowser/issues/7696
+                log.sessions.debug(f"Skipping invalid history item: {item}")
+                continue
+
             if item.url().scheme() == 'qute' and item.url().host() == 'back':
                 # don't add qute://back to the session file
                 if item_data.get('active', False) and data['history']:
@@ -264,7 +256,7 @@ class SessionManager(QObject):
                 data['history'].append(item_data)
         return data
 
-    def _save_all(self, *, only_window=None, with_private=False):
+    def _save_all(self, *, only_window=None, with_private=False, with_history=True):
         """Get a dict with data for all windows/tabs."""
         data: _JsonType = {'windows': []}
         if only_window is not None:
@@ -295,7 +287,8 @@ class SessionManager(QObject):
                 win_data['private'] = True
             for i, tab in enumerate(tabbed_browser.widgets()):
                 active = i == tabbed_browser.widget.currentIndex()
-                win_data['tabs'].append(self._save_tab(tab, active))
+                win_data['tabs'].append(self._save_tab(tab, active,
+                                                       with_history=with_history))
             data['windows'].append(win_data)
         return data
 
@@ -316,7 +309,7 @@ class SessionManager(QObject):
         return name
 
     def save(self, name, last_window=False, load_next_time=False,
-             only_window=None, with_private=False):
+             only_window=None, with_private=False, with_history=True):
         """Save a named session.
 
         Args:
@@ -327,6 +320,7 @@ class SessionManager(QObject):
             load_next_time: If set, prepares this session to be load next time.
             only_window: If set, only tabs in the specified window is saved.
             with_private: Include private windows.
+            with_history: Include tab history.
 
         Return:
             The name of the saved session.
@@ -342,7 +336,8 @@ class SessionManager(QObject):
                 return None
         else:
             data = self._save_all(only_window=only_window,
-                                  with_private=with_private)
+                                  with_private=with_private,
+                                  with_history=with_history)
         log.sessions.vdebug(  # type: ignore[attr-defined]
             "Saving data: {}".format(data))
         try:
@@ -443,7 +438,7 @@ class SessionManager(QObject):
             if histentry.get("last_visited"):
                 last_visited: Optional[QDateTime] = QDateTime.fromString(
                     histentry.get("last_visited"),
-                    Qt.ISODate,
+                    Qt.DateFormat.ISODate,
                 )
             else:
                 last_visited = None
@@ -465,7 +460,6 @@ class SessionManager(QObject):
         """Turn yaml data into windows."""
         window = mainwindow.MainWindow(geometry=win['geometry'],
                                        private=win.get('private', None))
-        window.show()
         tabbed_browser = objreg.get('tabbed-browser', scope='window',
                                     window=window.win_id)
         tab_to_focus = None
@@ -478,6 +472,8 @@ class SessionManager(QObject):
                 new_tab.set_pinned(True)
         if tab_to_focus is not None:
             tabbed_browser.widget.setCurrentIndex(tab_to_focus)
+
+        window.show()
         if win.get('active', False):
             QTimer.singleShot(0, tabbed_browser.widget.activateWindow)
 
@@ -557,31 +553,31 @@ def session_load(name: str, *,
     except SessionError as e:
         raise cmdutils.CommandError("Error while loading session: {}"
                                     .format(e))
-    else:
-        if clear:
-            for win in old_windows:
-                win.close()
-        if delete:
-            try:
-                session_manager.delete(name)
-            except SessionError as e:
-                log.sessions.exception("Error while deleting session!")
-                raise cmdutils.CommandError("Error while deleting session: {}"
-                                            .format(e))
-            else:
-                log.sessions.debug("Loaded & deleted session {}.".format(name))
+    if clear:
+        for win in old_windows:
+            win.close()
+    if delete:
+        try:
+            session_manager.delete(name)
+        except SessionError as e:
+            log.sessions.exception("Error while deleting session!")
+            raise cmdutils.CommandError("Error while deleting session: {}"
+                                        .format(e))
+        log.sessions.debug("Loaded & deleted session {}.".format(name))
 
 
 @cmdutils.register()
 @cmdutils.argument('name', completion=miscmodels.session)
 @cmdutils.argument('win_id', value=cmdutils.Value.win_id)
 @cmdutils.argument('with_private', flag='p')
+@cmdutils.argument('no_history', flag='n')
 def session_save(name: ArgType = default, *,
                  current: bool = False,
                  quiet: bool = False,
                  force: bool = False,
                  only_active_window: bool = False,
                  with_private: bool = False,
+                 no_history: bool = False,
                  win_id: int = None) -> None:
     """Save a session.
 
@@ -593,6 +589,7 @@ def session_save(name: ArgType = default, *,
         force: Force saving internal sessions (starting with an underline).
         only_active_window: Saves only tabs of the currently active window.
         with_private: Include private windows.
+        no_history: Don't store tab history.
     """
     if not isinstance(name, Sentinel) and name.startswith('_') and not force:
         raise cmdutils.CommandError("{} is an internal session, use --force "
@@ -605,16 +602,17 @@ def session_save(name: ArgType = default, *,
     try:
         if only_active_window:
             name = session_manager.save(name, only_window=win_id,
-                                        with_private=True)
+                                        with_private=True,
+                                        with_history=not no_history)
         else:
-            name = session_manager.save(name, with_private=with_private)
+            name = session_manager.save(name, with_private=with_private,
+                                        with_history=not no_history)
     except SessionError as e:
         raise cmdutils.CommandError("Error while saving session: {}".format(e))
+    if quiet:
+        log.sessions.debug("Saved session {}.".format(name))
     else:
-        if quiet:
-            log.sessions.debug("Saved session {}.".format(name))
-        else:
-            message.info("Saved session {}.".format(name))
+        message.info("Saved session {}.".format(name))
 
 
 @cmdutils.register()
@@ -637,8 +635,7 @@ def session_delete(name: str, *, force: bool = False) -> None:
         log.sessions.exception("Error while deleting session!")
         raise cmdutils.CommandError("Error while deleting session: {}"
                                     .format(e))
-    else:
-        log.sessions.debug("Deleted session {}.".format(name))
+    log.sessions.debug("Deleted session {}.".format(name))
 
 
 def load_default(name):
