@@ -10,7 +10,9 @@ import sys
 import contextlib
 import enum
 import argparse
-from typing import Iterator, Optional
+import tempfile
+from typing import Optional
+from collections.abc import Iterator
 
 from qutebrowser.qt.core import QStandardPaths
 from qutebrowser.qt.widgets import QApplication
@@ -18,7 +20,7 @@ from qutebrowser.qt.widgets import QApplication
 from qutebrowser.utils import log, debug, utils, version, qtutils
 
 # The cached locations
-_locations = {}
+_locations: dict["_Location", str] = {}
 
 
 class _Location(enum.Enum):
@@ -311,14 +313,15 @@ def _create(path: str) -> None:
         0700. If the destination directory exists already the permissions
         should not be changed.
     """
-    if APPNAME == 'qute_test' and path.startswith('/home'):  # pragma: no cover
-        for k, v in os.environ.items():
-            if k == 'HOME' or k.startswith('XDG_'):
-                log.init.debug(f"{k} = {v}")
-        raise AssertionError(
-            "Trying to create directory inside /home during "
-            "tests, this should not happen."
-        )
+    if APPNAME == 'qute_test':
+        if path.startswith('/home') and not path.startswith(tempfile.gettempdir()):  # pragma: no cover
+            for k, v in os.environ.items():
+                if k == 'HOME' or k.startswith('XDG_'):
+                    log.init.debug(f"{k} = {v}")
+            raise AssertionError(
+                "Trying to create directory inside /home during "
+                "tests, this should not happen."
+            )
     os.makedirs(path, 0o700, exist_ok=True)
 
 
