@@ -21,6 +21,7 @@ import pytest
 from qutebrowser.qt.core import QProcess, QPoint
 
 from helpers import testutils
+from end2end.fixtures import quteprocess
 from qutebrowser.utils import qtutils, utils, version
 
 
@@ -251,6 +252,7 @@ def test_optimize(request, quteproc_new, capfd, level):
 def test_version(request):
     """Test invocation with --version argument."""
     args = ['-m', 'qutebrowser', '--version'] + _base_args(request.config)
+    args.remove("--json-logging")
     # can't use quteproc_new here because it's confused by
     # early process termination
     proc = QProcess()
@@ -611,6 +613,26 @@ def test_service_worker_workaround(
         assert not service_worker_dir.exists()
 
 
+@pytest.mark.qt6_only
+def test_disable_hangouts_extension_crash(
+    quteproc_new: quteprocess.QuteProc,
+    request: pytest.FixtureRequest,
+    webengine_versions: version.WebEngineVersions,
+):
+    """Make sure disabling the Hangouts extension doesn't crash."""
+    args = _base_args(request.config) + [
+        '--temp-basedir',
+        '-s', 'qt.workarounds.disable_hangouts_extension', 'true',
+    ]
+    quteproc_new.start(args)
+    if webengine_versions.webengine == utils.VersionNumber(6, 10, 1):
+        line = quteproc_new.wait_for(message="Not disabling Hangouts extension *")
+        line.expected = True
+
+    quteproc_new.send_cmd(':quit')
+    quteproc_new.wait_for_quit()
+
+
 @pytest.mark.parametrize('store', [True, False])
 def test_cookies_store(quteproc_new, request, short_tmpdir, store):
     # Start test process
