@@ -1,30 +1,16 @@
-# vim: ft=python fileencoding=utf-8 sts=4 sw=4 et:
-
-# Copyright 2015-2021 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
-# Copyright 2015-2018 Daniel Schadt
+# SPDX-FileCopyrightText: Daniel Schadt
+# SPDX-FileCopyrightText: Florian Bruhin (The Compiler) <mail@qutebrowser.org>
 #
-# This file is part of qutebrowser.
-#
-# qutebrowser is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# qutebrowser is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with qutebrowser.  If not, see <https://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 """Tests for the custom TabWidget/TabBar."""
 
 import functools
 
 import pytest
-from PyQt5.QtGui import QIcon, QPixmap
+from unittest.mock import Mock
 
+from qutebrowser.qt.gui import QIcon, QPixmap
 from qutebrowser.mainwindow import tabwidget
 from qutebrowser.utils import usertypes
 
@@ -71,6 +57,38 @@ class TestTabWidget:
             assert first_size == widget.tabBar().tabSizeHint(i)
             assert first_size_min == widget.tabBar().minimumTabSizeHint(i)
 
+    @pytest.fixture
+    def paint_spy(self, monkeypatch):
+        spy = Mock()
+        monkeypatch.setattr(tabwidget, "QStylePainter", spy)
+        return spy
+
+    def test_tab_text_edlided_for_narrow_tabs(self, paint_spy, widget, fake_web_tab):
+        """Make sure text gets elided for narrow tabs."""
+        widget.setMaximumWidth(100)
+        widget.addTab(fake_web_tab(), "one two three four")
+
+        fake_paint_event = Mock()
+        fake_paint_event.region.return_value.intersects.return_value = True
+        widget.tabBar().paintEvent(fake_paint_event)
+
+        style_opt = paint_spy.return_value.drawControl.call_args_list[0][0][1]
+        assert len(style_opt.text) < len(widget.tabBar().tabText(0))
+        assert style_opt.text.endswith("…")
+        assert len(style_opt.text) > len("…")
+
+    def test_tab_text_not_edlided_for_wide_tabs(self, paint_spy, widget, fake_web_tab):
+        """Make sure text doesn't get elided for wide tabs."""
+        widget.setMaximumWidth(200)
+        widget.addTab(fake_web_tab(), "one two three four")
+
+        fake_paint_event = Mock()
+        fake_paint_event.region.return_value.intersects.return_value = True
+        widget.tabBar().paintEvent(fake_paint_event)
+
+        style_opt = paint_spy.return_value.drawControl.call_args_list[0][0][1]
+        assert style_opt.text.endswith(widget.tabBar().tabText(0))
+
     @pytest.mark.parametrize("shrink_pinned", [True, False])
     @pytest.mark.parametrize("vertical", [True, False])
     def test_pinned_size(self, widget, fake_web_tab, config_stub,
